@@ -18,7 +18,7 @@ require Data::Object::Autobox::String;
 require Data::Object::Autobox::Undef;
 require Data::Object::Autobox::Any;
 
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 sub import {
   my ($class) = @_;
@@ -40,7 +40,6 @@ sub import {
 }
 
 1;
-
 =encoding utf8
 
 =head1 NAME
@@ -61,10 +60,8 @@ Data-Object Autoboxing
 
   my $input  = [1,1,1,1,3,3,2,1,5,6,7,8,9];
   my $output = $input->grep(sub{$_[0] < 5})->unique->sort; # [1,2,3]
-  my $object = $output->array;
 
   $output->join(',')->print; # 1,2,3
-  $object->join(',')->print; # 1,2,3
 
   $object->isa('Data::Object::Array');
 
@@ -74,15 +71,47 @@ Data-Object Autoboxing
 
 This package implements autoboxing via L<autobox> to provide
 L<boxing|http://en.wikipedia.org/wiki/Object_type_(object-oriented_programming)>
-for native Perl 5 data types. This functionality is provided by L<Data::Object>
-which provides a collection of object classes for handling SCALAR, ARRAY, HASH,
-CODE, INTEGER, FLOAT, NUMBER, STRING, UNDEF, and other data type operations.
-
-Data::Object provides its own boxing strategy in that every method call which
-would normally return a native data type will return a data type object, but
-this functionality requires an initial data type object. Data::Object::Autobox
-makes it so that you do not need to explicitly create the initial data type
-object, and once the initial autobox method call is made, the Data::Object
-boxing takes over.
+for native Perl 5 data types.
 
 =cut
+
+=head1 AUTHOR
+
+Al Newkirk, C<awncorp@cpan.org>
+
+=head1 LICENSE
+
+Copyright (C) 2011-2019, Al Newkirk, et al.
+
+This is free software; you can redistribute it and/or modify it under the same
+terms as the Perl 5 programming language system itself.
+
+=head1 STATUS
+
+=begin html
+
+<a href="https://travis-ci.org/iamalnewkirk/data-object" target="_blank">
+<img src="https://travis-ci.org/iamalnewkirk/data-object.svg?branch=master"/>
+</a>
+
+=end html
+
+=head1 SEE ALSO
+
+To get the most out of this distribution, consider reading the following:
+
+L<Data::Object::Class>
+
+L<Data::Object::Role>
+
+L<Data::Object::Rule>
+
+L<Data::Object::Library>
+
+L<Data::Object::Signatures>
+
+L<Contributing|https://github.com/iamalnewkirk/data-object/CONTRIBUTING.mkdn>
+
+L<GitHub|https://github.com/iamalnewkirk/data-object>
+
+=cut
\ No newline at end of file
