@@ -3,7 +3,7 @@ package Data::Object::Base;
 use strict;
 use warnings;
 
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 # BUILD
 # METHODS
@@ -35,7 +35,6 @@ sub type {
 }
 
 1;
-
 =encoding utf8
 
 =head1 NAME
@@ -58,9 +57,8 @@ Data-Object Base Class
 
 =head1 DESCRIPTION
 
-Data::Object::Base is an abstract base class that mostly provides identity and
-classification for L<Data::Object> classes, and common routines for operating
-on any type of Data-Object object.
+This package provides an abstract base class used for identity and
+classification of L<Data::Object> classes.
 
 =cut
 
@@ -130,3 +128,44 @@ The type method returns object type string.
 =back
 
 =cut
+
+=head1 AUTHOR
+
+Al Newkirk, C<awncorp@cpan.org>
+
+=head1 LICENSE
+
+Copyright (C) 2011-2019, Al Newkirk, et al.
+
+This is free software; you can redistribute it and/or modify it under the same
+terms as the Perl 5 programming language system itself.
+
+=head1 STATUS
+
+=begin html
+
+<a href="https://travis-ci.org/iamalnewkirk/data-object" target="_blank">
+<img src="https://travis-ci.org/iamalnewkirk/data-object.svg?branch=master"/>
+</a>
+
+=end html
+
+=head1 SEE ALSO
+
+To get the most out of this distribution, consider reading the following:
+
+L<Data::Object::Class>
+
+L<Data::Object::Role>
+
+L<Data::Object::Rule>
+
+L<Data::Object::Library>
+
+L<Data::Object::Signatures>
+
+L<Contributing|https://github.com/iamalnewkirk/data-object/CONTRIBUTING.mkdn>
+
+L<GitHub|https://github.com/iamalnewkirk/data-object>
+
+=cut
\ No newline at end of file
