@@ -5,7 +5,7 @@ use warnings;
 
 use Data::Object::Export 'reify';
 
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 # BUILD
 
@@ -177,7 +177,6 @@ sub _formulate_wrt {
 # METHODS
 
 1;
-
 =encoding utf8
 
 =head1 NAME
@@ -208,9 +207,49 @@ Data-Object Class Configuration
 
 =head1 DESCRIPTION
 
-Data::Object::ClassHas modifies the consuming package with behaviors
-useful in defining classes. Specifically, this package wraps the C<has>
-attribute keyword functions and adds enhancements which as documented in
-L<Data::Object::Class>.
+This package modifies the consuming package with behaviors useful in defining
+classes. Specifically, this package wraps the C<has> attribute keyword
+functions and adds shortcuts and enhancements.
 
 =cut
+
+=head1 AUTHOR
+
+Al Newkirk, C<awncorp@cpan.org>
+
+=head1 LICENSE
+
+Copyright (C) 2011-2019, Al Newkirk, et al.
+
+This is free software; you can redistribute it and/or modify it under the same
+terms as the Perl 5 programming language system itself.
+
+=head1 STATUS
+
+=begin html
+
+<a href="https://travis-ci.org/iamalnewkirk/data-object" target="_blank">
+<img src="https://travis-ci.org/iamalnewkirk/data-object.svg?branch=master"/>
+</a>
+
+=end html
+
+=head1 SEE ALSO
+
+To get the most out of this distribution, consider reading the following:
+
+L<Data::Object::Class>
+
+L<Data::Object::Role>
+
+L<Data::Object::Rule>
+
+L<Data::Object::Library>
+
+L<Data::Object::Signatures>
+
+L<Contributing|https://github.com/iamalnewkirk/data-object/CONTRIBUTING.mkdn>
+
+L<GitHub|https://github.com/iamalnewkirk/data-object>
+
+=cut
\ No newline at end of file
