@@ -28,7 +28,7 @@ use overload (
 
 use parent 'Data::Object::Base::Code';
 
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 # BUILD
 # METHODS
@@ -168,7 +168,6 @@ sub rcurry {
 }
 
 1;
-
 =encoding utf8
 
 =head1 NAME
@@ -193,8 +192,7 @@ Data-Object Code Class
 
 =head1 DESCRIPTION
 
-Data::Object::Code provides routines for operating on Perl 5 code
-references. Code methods work on code references.
+This package provides routines for operating on Perl 5 code references.
 
 =cut
 
@@ -436,38 +434,43 @@ The self method returns the calling object (noop).
 
 =cut
 
-=head1 ROLES
+=head1 AUTHOR
 
-This package inherits all behavior from the folowing role(s):
+Al Newkirk, C<awncorp@cpan.org>
 
-=cut
+=head1 LICENSE
 
-=over 4
+Copyright (C) 2011-2019, Al Newkirk, et al.
 
-=item *
+This is free software; you can redistribute it and/or modify it under the same
+terms as the Perl 5 programming language system itself.
 
-L<Data::Object::Role::Detract>
+=head1 STATUS
 
-=item *
+=begin html
 
-L<Data::Object::Role::Dumper>
+<a href="https://travis-ci.org/iamalnewkirk/data-object" target="_blank">
+<img src="https://travis-ci.org/iamalnewkirk/data-object.svg?branch=master"/>
+</a>
 
-=item *
+=end html
 
-L<Data::Object::Role::Throwable>
+=head1 SEE ALSO
 
-=back
+To get the most out of this distribution, consider reading the following:
 
-=head1 RULES
+L<Data::Object::Class>
 
-This package adheres to the requirements in the folowing rule(s):
+L<Data::Object::Role>
 
-=cut
+L<Data::Object::Rule>
 
-=over 4
+L<Data::Object::Library>
 
-=item *
+L<Data::Object::Signatures>
 
-L<Data::Object::Rule::Defined>
+L<Contributing|https://github.com/iamalnewkirk/data-object/CONTRIBUTING.mkdn>
 
-=back
+L<GitHub|https://github.com/iamalnewkirk/data-object>
+
+=cut
\ No newline at end of file
