@@ -5,7 +5,7 @@ use warnings;
 
 use Import::Into;
 
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 # BUILD
 
@@ -119,6 +119,11 @@ sub choose {
     return 'config_string';
   }
 
+  # config struct
+  if (subject($type, 'struct')) {
+    return 'config_struct';
+  }
+
   # config type
   if (subject($type, 'type')) {
     return 'config_type';
@@ -149,11 +154,6 @@ sub choose {
     return 'config_rule';
   }
 
-  # config try
-  if (subject($type, 'try')) {
-    return 'config_try';
-  }
-
   return;
 }
 
@@ -430,12 +430,6 @@ sub config_string {
   ]
 }
 
-sub config_try {
-  [
-    prepare_use('Try::Tiny')
-  ]
-}
-
 sub config_type {
   [
     @{config_class()},
@@ -531,7 +525,6 @@ sub _process_typetiny {
 }
 
 1;
-
 =encoding utf8
 
 =head1 NAME
@@ -548,14 +541,282 @@ Data-Object Package Configuration
 
 =head1 SYNOPSIS
 
-  use Data::Object::Config;
+  use Data::Object::Config 'Core';
 
 =cut
 
 =head1 DESCRIPTION
 
-Data::Object::Config is used to configure the consuming package based on
-arguments passed to the import statement.
+This package is used to configure the consuming package based on arguments
+passed to the import statement.
+
+=head1 CONFIGURATIONS
+
+This package is used by both L<Do> and L<Data::Object> to configure the calling
+namespace.
+
+=head2 core
+
+  package main;
+
+  use Data::Object::Config 'Core';
+
+  fun main() {
+    # ...
+  }
+
+  1;
+
+The core configuration enables strict, warnings, Perl's 5.14 features, and
+configures the core type library, method signatures, and autoboxing.
+
+=head2 library
+
+  package App::Library;
+
+  use Data::Object::Config 'Library';
+
+  our $User = declare 'User',
+    as InstanceOf["App::User"];
+
+  1;
+
+The library configuration established a L<Type::Library> compliant type
+library, as well as configuring L<Type::Utils> in the calling package.  Read
+more at L<Data::Object::Library>.
+
+=head2 class
+
+  package App::User;
+
+  use Data::Object::Config 'Class';
+
+  has 'fname';
+  has 'lname';
+
+  1;
+
+The class configuration configures the calling package as a Moo class, having
+the "has", "with", and "extends" keywords available. Read more at
+L<Data::Object::Class>.
+
+=head2 role
+
+  package App::Queuer;
+
+  use Data::Object::Config 'Role';
+
+  has 'queue';
+
+  method dequeue() {
+    # ...
+  }
+
+  method enqueue($job) {
+    # ...
+  }
+
+  1;
+
+The role configuration configures the calling package as a Moo role, having the
+"has", "with", and "extends" keywords available. Read more at
+L<Data::Object::Role>.
+
+=head2 rule
+
+  package App::Queueable;
+
+  use Data::Object::Config 'Rule';
+
+  requires 'dequeue';
+  requires 'enqueue';
+
+  1;
+
+The rule configuration configures the calling package as a Moo role, intended
+to be used to classify interfaces. Read more at L<Data::Object::Rule>.
+
+=head2 state
+
+  package App::Env;
+
+  use Data::Object::Config 'State';
+
+  has 'vars';
+  has 'args';
+  has 'opts';
+
+  1;
+
+The state configuration configures the calling package as a singleton class
+with global state. Read more at L<Data::Object::State>.
+
+=head2 struct
+
+  package App::Data;
+
+  use Data::Object::Config 'Struct';
+
+  has 'auth';
+  has 'user';
+  has 'args';
+
+  1;
+
+The struct configuration configures the calling package as a class whose state
+becomes immutable after instantiation. Read more at L<Data::Object::Struct>.
+
+=head2 array
+
+  package App::Args;
+
+  use Data::Object::Config 'Array';
+
+  method command() {
+    return $self->get(0);
+  }
+
+  1;
+
+The array configuration configures the calling package as a class which extends
+the Array class. Read more at L<Data::Object::Array>.
+
+=head2 code
+
+  package App::Func;
+
+  use Data::Object::Config 'Code';
+
+  around BUILD($args) {
+    $self->$orig($args);
+
+    # ...
+  }
+
+  1;
+
+The code configuration configures the calling package as a class which extends
+the Code class. Read more at L<Data::Object::Code>.
+
+=head2 float
+
+  package App::Amount;
+
+  use Data::Object::Config 'Float';
+
+  method currency(Str $code) {
+    # ...
+  }
+
+  1;
+
+The float configuration configures the calling package as a class which extends
+the Float class. Read more at L<Data::Object::Float>.
+
+=head2 hash
+
+  package App::Data;
+
+  use Data::Object::Config 'Hash';
+
+  method logline() {
+    # ...
+  }
+
+  1;
+
+The hash configuration configures the calling package as a class which extends
+the Hash class. Read more at L<Data::Object::Hash>.
+
+=head2 integer
+
+  package App::Phone;
+
+  use Data::Object::Config 'Integer';
+
+  method format(Str $code) {
+    # ...
+  }
+
+  1;
+
+The integer configuration configures the calling package as a class which
+extends the Integer class. Read more at L<Data::Object::Integer>.
+
+=head2 number
+
+  package App::ID;
+
+  use Data::Object::Config 'Number';
+
+  method find() {
+    # ...
+  }
+
+  1;
+
+The number configuration configures the calling package as a class which
+extends the Number class. Read more at L<Data::Object::Number>.
+
+=head2 regexp
+
+  package App::Path;
+
+  use Data::Object::Config 'Regexp';
+
+  method match() {
+    # ...
+  }
+
+  1;
+
+The regexp configuration configures the calling package as a class which
+extends the Regexp class. Read more at L<Data::Object::Regexp>.
+
+=head2 scalar
+
+  package App::OID;
+
+  use Data::Object::Config 'Scalar';
+
+  method find() {
+    # ...
+  }
+
+  1;
+
+The scalar configuration configures the calling package as a class which
+extends the Scalar class. Read more at L<Data::Object::Scalar>.
+
+=head2 string
+
+  package App::Title;
+
+  use Data::Object::Config 'String';
+
+  method generate() {
+    # ...
+  }
+
+  1;
+
+The string configuration configures the calling package as a class which
+extends the String class. Read more at L<Data::Object::String>.
+
+=head2 undef
+
+  package App::Fail;
+
+  use Data::Object::Config 'Undef';
+
+  method explain() {
+    # ...
+  }
+
+  1;
+
+The undef configuration configures the calling package as a class which extends
+the Undef class. Read more at L<Data::Object::Undef>.
 
 =cut
 
@@ -939,23 +1200,6 @@ L<Data::Object::Class> which extends L<Data::Object::String>.
 
 =cut
 
-=head2 config_try
-
-  config_try() : ArrayRef
-
-The config_try function returns plans for configuring the package to have
-C<try> and C<catch> constructs for trapping exceptions.
-
-=over 4
-
-=item config_try example
-
-  my $plans = config_try;
-
-=back
-
-=cut
-
 =head2 config_type
 
   config_type() : ArrayRef
@@ -1154,14 +1398,56 @@ The process_use function executes the use-plan on behalf of the caller.
 
   subject(Str $arg1, Str $arg2) : Int
 
-The subject function returns truthy if both arguments match alphanumerically (not case-sensitive).
+The subject function returns truthy if both arguments match alphanumerically
+(not case-sensitive).
 
 =over 4
 
 =item subject example
 
-  subject('-Role', 'Role');
+  subject('Role', 'Role');
 
 =back
 
 =cut
+
+=head1 AUTHOR
+
+Al Newkirk, C<awncorp@cpan.org>
+
+=head1 LICENSE
+
+Copyright (C) 2011-2019, Al Newkirk, et al.
+
+This is free software; you can redistribute it and/or modify it under the same
+terms as the Perl 5 programming language system itself.
+
+=head1 STATUS
+
+=begin html
+
+<a href="https://travis-ci.org/iamalnewkirk/data-object" target="_blank">
+<img src="https://travis-ci.org/iamalnewkirk/data-object.svg?branch=master"/>
+</a>
+
+=end html
+
+=head1 SEE ALSO
+
+To get the most out of this distribution, consider reading the following:
+
+L<Data::Object::Class>
+
+L<Data::Object::Role>
+
+L<Data::Object::Rule>
+
+L<Data::Object::Library>
+
+L<Data::Object::Signatures>
+
+L<Contributing|https://github.com/iamalnewkirk/data-object/CONTRIBUTING.mkdn>
+
+L<GitHub|https://github.com/iamalnewkirk/data-object>
+
+=cut
\ No newline at end of file
