@@ -28,7 +28,7 @@ use overload (
 
 use parent 'Data::Object::Base::Regexp';
 
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 # BUILD
 # METHODS
@@ -91,7 +91,6 @@ sub replace {
 }
 
 1;
-
 =encoding utf8
 
 =head1 NAME
@@ -116,9 +115,7 @@ Data-Object Regexp Class
 
 =head1 DESCRIPTION
 
-Data::Object::Regexp provides routines for operating on Perl 5 regular
-expressions. Data::Object::Regexp methods work on data that meets the criteria
-for being a regular expression.
+This package provides routines for operating on Perl 5 regular expressions.
 
 =cut
 
@@ -142,7 +139,7 @@ L<Data::Object::Number> object.
 
   # given $regexp
 
-  $regexp->defined; # 1
+  $re->defined; # 1
 
 =back
 
@@ -185,7 +182,7 @@ returns a L<Data::Object::Array> object.
 
   # given $regexp
 
-  $regexp->roles;
+  $re->roles;
 
 =back
 
@@ -201,7 +198,7 @@ The rules method returns consumed rules.
 
 =item rules example
 
-  my $rules = $regexp->rules();
+  my $rules = $re->rules;
 
 =back
 
@@ -228,42 +225,43 @@ can be used to introspect the result of the operation.
 
 =cut
 
-=head1 ROLES
+=head1 AUTHOR
 
-This package inherits all behavior from the folowing role(s):
+Al Newkirk, C<awncorp@cpan.org>
 
-=cut
+=head1 LICENSE
 
-=over 4
+Copyright (C) 2011-2019, Al Newkirk, et al.
 
-=item *
+This is free software; you can redistribute it and/or modify it under the same
+terms as the Perl 5 programming language system itself.
 
-L<Data::Object::Role::Detract>
+=head1 STATUS
 
-=item *
+=begin html
 
-L<Data::Object::Role::Dumper>
+<a href="https://travis-ci.org/iamalnewkirk/data-object" target="_blank">
+<img src="https://travis-ci.org/iamalnewkirk/data-object.svg?branch=master"/>
+</a>
 
-=item *
+=end html
 
-L<Data::Object::Role::Output>
+=head1 SEE ALSO
 
-=item *
+To get the most out of this distribution, consider reading the following:
 
-L<Data::Object::Role::Throwable>
+L<Data::Object::Class>
 
-=back
+L<Data::Object::Role>
 
-=head1 RULES
+L<Data::Object::Rule>
 
-This package adheres to the requirements in the folowing rule(s):
+L<Data::Object::Library>
 
-=cut
+L<Data::Object::Signatures>
 
-=over 4
+L<Contributing|https://github.com/iamalnewkirk/data-object/CONTRIBUTING.mkdn>
 
-=item *
+L<GitHub|https://github.com/iamalnewkirk/data-object>
 
-L<Data::Object::Rule::Defined>
-
-=back
+=cut
\ No newline at end of file
