@@ -4,11 +4,12 @@ use strict;
 use warnings;
 
 use Data::Object::State;
+
 use Memoize;
 
 use parent 'Data::Object::Base';
 
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 # METHODS
 
@@ -81,7 +82,6 @@ sub tns {
 }
 
 1;
-
 =encoding utf8
 
 =head1 NAME
@@ -106,8 +106,8 @@ Data-Object Namespace Registry
 
 =head1 DESCRIPTION
 
-Data::Object::Registry is a singleton that holds mappings for namespaces and
-type libraries.
+This package is a singleton that holds mappings for namespaces and type
+libraries.
 
 =cut
 
@@ -212,3 +212,44 @@ Returns the registered type-namespaces.
 =back
 
 =cut
+
+=head1 AUTHOR
+
+Al Newkirk, C<awncorp@cpan.org>
+
+=head1 LICENSE
+
+Copyright (C) 2011-2019, Al Newkirk, et al.
+
+This is free software; you can redistribute it and/or modify it under the same
+terms as the Perl 5 programming language system itself.
+
+=head1 STATUS
+
+=begin html
+
+<a href="https://travis-ci.org/iamalnewkirk/data-object" target="_blank">
+<img src="https://travis-ci.org/iamalnewkirk/data-object.svg?branch=master"/>
+</a>
+
+=end html
+
+=head1 SEE ALSO
+
+To get the most out of this distribution, consider reading the following:
+
+L<Data::Object::Class>
+
+L<Data::Object::Role>
+
+L<Data::Object::Rule>
+
+L<Data::Object::Library>
+
+L<Data::Object::Signatures>
+
+L<Contributing|https://github.com/iamalnewkirk/data-object/CONTRIBUTING.mkdn>
+
+L<GitHub|https://github.com/iamalnewkirk/data-object>
+
+=cut
\ No newline at end of file
