@@ -5,7 +5,7 @@ use warnings;
 
 use Data::Object::Role;
 
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 # BUILD
 # METHODS
@@ -35,7 +35,6 @@ sub dump {
 }
 
 1;
-
 =encoding utf8
 
 =head1 NAME
@@ -60,8 +59,7 @@ Data-Object Dumper Role
 
 =head1 DESCRIPTION
 
-Data::Object::Role::Dumper provides routines for operating on Perl 5 data
-objects which meet the criteria for being dumpable.
+This role provides functionality for dumping the object and underlying value.
 
 =cut
 
@@ -86,3 +84,44 @@ The dump method returns a string representation of the underlying data.
 =back
 
 =cut
+
+=head1 AUTHOR
+
+Al Newkirk, C<awncorp@cpan.org>
+
+=head1 LICENSE
+
+Copyright (C) 2011-2019, Al Newkirk, et al.
+
+This is free software; you can redistribute it and/or modify it under the same
+terms as the Perl 5 programming language system itself.
+
+=head1 STATUS
+
+=begin html
+
+<a href="https://travis-ci.org/iamalnewkirk/data-object" target="_blank">
+<img src="https://travis-ci.org/iamalnewkirk/data-object.svg?branch=master"/>
+</a>
+
+=end html
+
+=head1 SEE ALSO
+
+To get the most out of this distribution, consider reading the following:
+
+L<Data::Object::Class>
+
+L<Data::Object::Role>
+
+L<Data::Object::Rule>
+
+L<Data::Object::Library>
+
+L<Data::Object::Signatures>
+
+L<Contributing|https://github.com/iamalnewkirk/data-object/CONTRIBUTING.mkdn>
+
+L<GitHub|https://github.com/iamalnewkirk/data-object>
+
+=cut
\ No newline at end of file
