@@ -7,7 +7,7 @@ use Data::Object::Role;
 
 use Readonly;
 
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 # METHODS
 
@@ -22,7 +22,6 @@ sub immutable {
 }
 
 1;
-
 =encoding utf8
 
 =head1 NAME
@@ -39,32 +38,22 @@ Data-Object Immutability Role
 
 =head1 SYNOPSIS
 
-
-  package Entity;
-
-  use Data::Object 'Class';
+  use Data::Object::Class;
+  use Data::Object::Signatures;
 
   with 'Data::Object::Role::Immutable';
 
-  has 'name';
-
   method BUILD($args) {
     $self->immutable;
 
     return $args;
   }
 
-  1;
-
 =cut
 
 =head1 DESCRIPTION
 
-This package provides a mechanism for making any L<Data::Object> data type
-object immutable. An immutable object is an object whose state cannot be
-modified after it is created; Immutable objects are often useful because they
-are inherently thread-safe, easier to reason about, and offer higher security
-than mutable objects.
+This package provides a mechanism for making any derived object immutable.
 
 =cut
 
@@ -90,3 +79,44 @@ is made to modify the underlying value.
 =back
 
 =cut
+
+=head1 AUTHOR
+
+Al Newkirk, C<awncorp@cpan.org>
+
+=head1 LICENSE
+
+Copyright (C) 2011-2019, Al Newkirk, et al.
+
+This is free software; you can redistribute it and/or modify it under the same
+terms as the Perl 5 programming language system itself.
+
+=head1 STATUS
+
+=begin html
+
+<a href="https://travis-ci.org/iamalnewkirk/data-object" target="_blank">
+<img src="https://travis-ci.org/iamalnewkirk/data-object.svg?branch=master"/>
+</a>
+
+=end html
+
+=head1 SEE ALSO
+
+To get the most out of this distribution, consider reading the following:
+
+L<Data::Object::Class>
+
+L<Data::Object::Role>
+
+L<Data::Object::Rule>
+
+L<Data::Object::Library>
+
+L<Data::Object::Signatures>
+
+L<Contributing|https://github.com/iamalnewkirk/data-object/CONTRIBUTING.mkdn>
+
+L<GitHub|https://github.com/iamalnewkirk/data-object>
+
+=cut
\ No newline at end of file
