@@ -7,7 +7,7 @@ use Data::Object::Role;
 
 use Carp ();
 
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 # BUILD
 
@@ -38,7 +38,6 @@ sub DESTROY {
 # METHODS
 
 1;
-
 =encoding utf8
 
 =head1 NAME
@@ -60,23 +59,19 @@ Data-Object Proxyable Role
   with 'Data::Object::Role::Proxyable';
 
   sub BUILDPROXY {
-
     my ($class, $method, @args) = @_;
 
     return if $method eq 'execute'; # die with method missing error
 
     return sub { time }; # process method call
-
   }
 
 =cut
 
 =head1 DESCRIPTION
 
-Data::Object::Role::Proxyable provides a mechanism for operating on Perl 5
-data objects which meet the criteria for being proxyable. This role provides a
-wrapper around the AUTOLOAD routine which processes calls to routines which
-don't exist.
+This role provides a wrapper around the AUTOLOAD routine which processes calls
+to routines which don't exist.
 
 =cut
 
@@ -119,3 +114,44 @@ called and handled automatically.
 =back
 
 =cut
+
+=head1 AUTHOR
+
+Al Newkirk, C<awncorp@cpan.org>
+
+=head1 LICENSE
+
+Copyright (C) 2011-2019, Al Newkirk, et al.
+
+This is free software; you can redistribute it and/or modify it under the same
+terms as the Perl 5 programming language system itself.
+
+=head1 STATUS
+
+=begin html
+
+<a href="https://travis-ci.org/iamalnewkirk/data-object" target="_blank">
+<img src="https://travis-ci.org/iamalnewkirk/data-object.svg?branch=master"/>
+</a>
+
+=end html
+
+=head1 SEE ALSO
+
+To get the most out of this distribution, consider reading the following:
+
+L<Data::Object::Class>
+
+L<Data::Object::Role>
+
+L<Data::Object::Rule>
+
+L<Data::Object::Library>
+
+L<Data::Object::Signatures>
+
+L<Contributing|https://github.com/iamalnewkirk/data-object/CONTRIBUTING.mkdn>
+
+L<GitHub|https://github.com/iamalnewkirk/data-object>
+
+=cut
\ No newline at end of file
