@@ -11,7 +11,7 @@ use overload (
   fallback => 1
 );
 
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 # BUILD
 # METHODS
@@ -121,7 +121,6 @@ sub string {
 }
 
 1;
-
 =encoding utf8
 
 =head1 NAME
@@ -132,7 +131,7 @@ Data::Object::Search
 
 =head1 ABSTRACT
 
-Data-Object Regex Class
+Data-Object Search Class
 
 =cut
 
@@ -154,9 +153,8 @@ Data-Object Regex Class
 
 =head1 DESCRIPTION
 
-Data::Object::Search provides routines for introspecting the results of an
-operation involving a regular expressions. These methods work on data whose
-shape conforms to the tuple defined in the synopsis.
+This package provides routines for introspecting the results of a regexp search
+operation.
 
 =cut
 
@@ -276,7 +274,6 @@ expression operation.
 
   name() : StrObject
 
-
 The named_captures method returns a hash containing the requested named regular
 expressions and captured string pairs from the result object which contains
 information about the results of the regular expression operation.
@@ -363,54 +360,43 @@ regular expression operation.
 
 =cut
 
-=head1 ROLES
+=head1 AUTHOR
 
-This package inherits all behavior from the folowing role(s):
+Al Newkirk, C<awncorp@cpan.org>
 
-=cut
+=head1 LICENSE
 
-=over 4
+Copyright (C) 2011-2019, Al Newkirk, et al.
 
-=item *
+This is free software; you can redistribute it and/or modify it under the same
+terms as the Perl 5 programming language system itself.
 
-L<Data::Object::Role::Detract>
+=head1 STATUS
 
-=item *
+=begin html
 
-L<Data::Object::Role::Dumper>
+<a href="https://travis-ci.org/iamalnewkirk/data-object" target="_blank">
+<img src="https://travis-ci.org/iamalnewkirk/data-object.svg?branch=master"/>
+</a>
 
-=item *
+=end html
 
-L<Data::Object::Role::Output>
+=head1 SEE ALSO
 
-=item *
+To get the most out of this distribution, consider reading the following:
 
-L<Data::Object::Role::Throwable>
+L<Data::Object::Class>
 
-=back
+L<Data::Object::Role>
 
-=head1 RULES
+L<Data::Object::Rule>
 
-This package adheres to the requirements in the folowing rule(s):
+L<Data::Object::Library>
 
-=cut
+L<Data::Object::Signatures>
 
-=over 4
+L<Contributing|https://github.com/iamalnewkirk/data-object/CONTRIBUTING.mkdn>
 
-=item *
+L<GitHub|https://github.com/iamalnewkirk/data-object>
 
-L<Data::Object::Rule::Collection>
-
-=item *
-
-L<Data::Object::Rule::Comparison>
-
-=item *
-
-L<Data::Object::Rule::Defined>
-
-=item *
-
-L<Data::Object::Rule::List>
-
-=back
+=cut
\ No newline at end of file
