@@ -7,7 +7,7 @@ use Function::Parameters;
 
 use Data::Object::Export 'namespace', 'reify';
 
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 # BUILD
 
@@ -137,7 +137,6 @@ sub arnd_settings {
 # METHODS
 
 1;
-
 =encoding utf8
 
 =head1 NAME
@@ -160,13 +159,22 @@ Data-Object Signatures Configuration
     return "Hello $name, how are you?";
   }
 
+  around created() {
+    # do something ...
+    return $self->$orig;
+  }
+
+  around updated() {
+    # do something ...
+    return $self->$orig;
+  }
+
 =cut
 
 =head1 DESCRIPTION
 
-Data::Object::Signatures is a subclass of L<Type::Tiny::Signatures> providing
-method and function signatures supporting all the type constraints provided by
-L<Data::Object::Config::Type>.
+This package is provides method and function signatures supporting all the type
+constraints provided by L<Data::Object::Library>.
 
 =cut
 
@@ -272,3 +280,44 @@ configuration.
 =back
 
 =cut
+
+=head1 AUTHOR
+
+Al Newkirk, C<awncorp@cpan.org>
+
+=head1 LICENSE
+
+Copyright (C) 2011-2019, Al Newkirk, et al.
+
+This is free software; you can redistribute it and/or modify it under the same
+terms as the Perl 5 programming language system itself.
+
+=head1 STATUS
+
+=begin html
+
+<a href="https://travis-ci.org/iamalnewkirk/data-object" target="_blank">
+<img src="https://travis-ci.org/iamalnewkirk/data-object.svg?branch=master"/>
+</a>
+
+=end html
+
+=head1 SEE ALSO
+
+To get the most out of this distribution, consider reading the following:
+
+L<Data::Object::Class>
+
+L<Data::Object::Role>
+
+L<Data::Object::Rule>
+
+L<Data::Object::Library>
+
+L<Data::Object::Signatures>
+
+L<Contributing|https://github.com/iamalnewkirk/data-object/CONTRIBUTING.mkdn>
+
+L<GitHub|https://github.com/iamalnewkirk/data-object>
+
+=cut
\ No newline at end of file
