@@ -5,7 +5,7 @@ use warnings;
 
 use parent 'Data::Object::Class';
 
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 # BUILD
 
@@ -53,7 +53,6 @@ sub renew {
 }
 
 1;
-
 =encoding utf8
 
 =head1 NAME
@@ -72,15 +71,17 @@ Data-Object Singleton Declaration
 
   package Registry;
 
-  use Data::Object 'State';
+  use Data::Object::State;
 
   extends 'Environment';
 
+  1;
+
 =cut
 
 =head1 DESCRIPTION
 
-Data::Object::State modifies the consuming package makes it a singleton class.
+This package modifies the consuming package making it a singleton.
 
 =cut
 
@@ -105,3 +106,44 @@ The renew method resets the state and returns a new singleton.
 =back
 
 =cut
+
+=head1 AUTHOR
+
+Al Newkirk, C<awncorp@cpan.org>
+
+=head1 LICENSE
+
+Copyright (C) 2011-2019, Al Newkirk, et al.
+
+This is free software; you can redistribute it and/or modify it under the same
+terms as the Perl 5 programming language system itself.
+
+=head1 STATUS
+
+=begin html
+
+<a href="https://travis-ci.org/iamalnewkirk/data-object" target="_blank">
+<img src="https://travis-ci.org/iamalnewkirk/data-object.svg?branch=master"/>
+</a>
+
+=end html
+
+=head1 SEE ALSO
+
+To get the most out of this distribution, consider reading the following:
+
+L<Data::Object::Class>
+
+L<Data::Object::Role>
+
+L<Data::Object::Rule>
+
+L<Data::Object::Library>
+
+L<Data::Object::Signatures>
+
+L<Contributing|https://github.com/iamalnewkirk/data-object/CONTRIBUTING.mkdn>
+
+L<GitHub|https://github.com/iamalnewkirk/data-object>
+
+=cut
\ No newline at end of file
