@@ -29,7 +29,7 @@ use overload (
 
 use parent 'Data::Object::Base::String';
 
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 # BUILD
 # METHODS
@@ -525,7 +525,6 @@ sub words {
 }
 
 1;
-
 =encoding utf8
 
 =head1 NAME
@@ -550,13 +549,7 @@ Data-Object String Class
 
 =head1 DESCRIPTION
 
-Data::Object::String provides routines for operating on Perl 5 string
-data. String methods work on data that meets the criteria for being a string. A
-string holds and manipulates an arbitrary sequence of bytes, typically
-representing characters. Users of strings should be aware of the methods that
-modify the string itself as opposed to returning a new string. Unless stated, it
-may be safe to assume that the following methods copy, modify and return new
-strings based on their function.
+This package provides routines for operating on Perl 5 string data.
 
 =cut
 
@@ -1273,46 +1266,43 @@ array reference. This method returns an array value.
 
 =cut
 
-=head1 ROLES
+=head1 AUTHOR
 
-This package inherits all behavior from the folowing role(s):
+Al Newkirk, C<awncorp@cpan.org>
 
-=cut
+=head1 LICENSE
 
-=over 4
+Copyright (C) 2011-2019, Al Newkirk, et al.
 
-=item *
+This is free software; you can redistribute it and/or modify it under the same
+terms as the Perl 5 programming language system itself.
 
-L<Data::Object::Role::Detract>
+=head1 STATUS
 
-=item *
+=begin html
 
-L<Data::Object::Role::Dumper>
+<a href="https://travis-ci.org/iamalnewkirk/data-object" target="_blank">
+<img src="https://travis-ci.org/iamalnewkirk/data-object.svg?branch=master"/>
+</a>
 
-=item *
+=end html
 
-L<Data::Object::Role::Output>
+=head1 SEE ALSO
 
-=item *
+To get the most out of this distribution, consider reading the following:
 
-L<Data::Object::Role::Throwable>
+L<Data::Object::Class>
 
-=back
+L<Data::Object::Role>
 
-=head1 RULES
+L<Data::Object::Rule>
 
-This package adheres to the requirements in the folowing rule(s):
+L<Data::Object::Library>
 
-=cut
+L<Data::Object::Signatures>
 
-=over 4
+L<Contributing|https://github.com/iamalnewkirk/data-object/CONTRIBUTING.mkdn>
 
-=item *
+L<GitHub|https://github.com/iamalnewkirk/data-object>
 
-L<Data::Object::Rule::Comparison>
-
-=item *
-
-L<Data::Object::Rule::Defined>
-
-=back
+=cut
\ No newline at end of file
